#!/usr/bin/python3
'''
Driver for GPS client daemon with logging setup.
'''

import os
from clazzes.tools.logtools import configureLogging
import configparser
from clazzes.tools.lang import get_or_default
from clazzes.gpsclient.logserver import run_server
import pkg_resources
import signal

interruptor = None

def main():
    
    import logging
    
    log = logging.getLogger(__name__)
    
    try:
        conffile = os.getenv("GPSTRACK_RUNNER_CONF","/etc/gpstrack-runner/runner.cnf")
        
        try:
            version = pkg_resources.get_distribution("clazzes_gpsclient").version
        except pkg_resources.DistributionNotFound:
            version = "svn"
        
        log.info("Starting gpstrack-runner-%s with config from [%s]"%(version,conffile))
        
        def sighandler(signum,fram):
            global interruptor
            log.info("gpstrack-runner interrupted by signal [%d]"%signum)
            if interruptor:
                interruptor()
    
        def _register_interruptor(_interruptor):
            global interruptor
            interruptor = _interruptor
    
        config = configparser.ConfigParser()
        config.optionxform = lambda option: option
    
        config.read(conffile)
        
        options = config["runner"]
        
        url = options.get("source","file:///var/spool/gpstrack-runner?fake_timestamps=true")
        interval = get_or_default(options,"interval",1.0)
        
        listen_url = options.get("listen_url","tcp://localhost:2948")
    
        signal.signal(signal.SIGINT,sighandler)
        signal.signal(signal.SIGHUP,sighandler)
        signal.signal(signal.SIGTERM,sighandler)
        signal.signal(signal.SIGQUIT,sighandler)
    
        log.info("Listening on [%s], serving log files from [%s] with interval [%ss]"%(listen_url,url,interval))
    
        run_server(listen_url,url,interval,_register_interruptor)
    
        log.info("gpstrack-runner finished.")
    except:
        log.exception("gpstrack-runner terminated upon unexpected exception")
    
if __name__ == "__main__":
    
    logconf = os.getenv("GPSTRACK_RUNNER_LOGCONF","/etc/gpstrack-runner/logging.json")
    configureLogging(logconf)

    main()
