'''

  Factory for creating a chain of GPS client delegation chain
  for a given URL
'''

from clazzes.gpsclient.gpsd import GPSDClient
from clazzes.gpsclient.loop import Loop
from clazzes.gpsclient.throttle import Throttle
from clazzes.gpsclient.fake import FakeTimestamps, ShiftTimestamps

import os
from urllib import parse

def new_client(url,export_comments=False):
    
    if isinstance(url,str):
        url = parse.urlparse(url)
        
    options = parse.parse_qs(url.query)
    
    if "endless" in options or (url.scheme in ('','file') and os.path.isdir(url.path)):
        client = Loop(export_comments=export_comments)
    else:
        client = GPSDClient(export_comments=export_comments)
    
    if "interval" in options:
        client = Throttle(client)
        
    if "start_timestamp" in options:
        client = ShiftTimestamps(client)

    if "fake_timestamps" in options:
        client = FakeTimestamps(client)

    return client